---
title: What are the licensing requirements? 
layout: page 
date: 2014-01-12
---

Urubu is licensed under the [software_license].

The first thing to understand is that this license applies only to the Urubu
software. It has no implications on website projects managed with Urubu. You
are free to license your projects in any way you choose.

The license only becomes relevant when you release a modified version of the
Urubu software to the public in some way. In that case, you have to release the
modified source code also, under the same license. 

With the original GPL, a release meant shipping software to user that would
install and run it locally.  However, these days software is often made
available by running it on a server.  Under the original GPL, there would be no
requirement to release the modified source code in such as case. This clearly
violates the spirit of the GNU Licenses.

The [software_license] fixes that problem. If you make the modified software
available by running it on a server, you have to make the modified source code
available to the users under the same license.

